/*
Description:
A widget that dynamically creates a vertical/horizontal stepper for incoming data. The user can pass a list of steps
that are converted to stepper states using length of the array.

Usage:
The user passes a List of CustomSteps that define the different steps in a Stepper.
The user can also define different functionality and parameters using the StepperParameter class.
Refer to CustomSteps and StepperParameter class definition for more details.
Moreover, the user can provide custom definition for Cancel, Tap and Continue Stepper actions.

	List<CustomSteps> steps = [
		CustomStep(...),
		CustomStep(...)
	];
	StepperParameters stepperParams = new StepperParameters(type: StepperType.vertical);
	Function(int, String) onTapped{...}
	Function(int, String) onCancel{...}
	Function(int, String) onContinue{...}

	CustomStepper(steps, stepperParams, onTapped, onCancel, onContinue);

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

class CustomStepper extends StatefulWidget {
  List<CustomSteps> steps;
  StepperParameters stepperParams;
  Function(int, String) onTapped;
  Function(int, String) onContinue;
  Function(int, String) onCancel;
  CustomStepper(this.steps, this.stepperParams, this.onTapped, this.onContinue,
      this.onCancel);

  @override
  _customStepper createState() => new _customStepper(this.steps,
      this.stepperParams, this.onTapped, this.onContinue, this.onCancel);
}

class _customStepper extends State<CustomStepper> {
  List<CustomSteps> steps;
  StepperParameters stepperParams;
  Function(int, String) onTapped;
  Function(int, String) onContinue;
  Function(int, String) onCancel;
  _customStepper(this.steps, this.stepperParams, this.onTapped, this.onContinue,
      this.onCancel);

  int currentStep;
  bool complete;
  List<StepState> listState;

  @override
  void initState() {
    currentStep = 0;
    complete = false;
    listState = [
      StepState.indexed,
      StepState.editing,
      StepState.complete,
      StepState.disabled,
      StepState.error,
    ];
    super.initState();
  }

  List<Step> _createSteps(BuildContext context) {
    List<Step> stepArray = [];
    if (steps != null && steps.length != 0) {
      for (int step = 0; step < steps.length; step++) {
        stepArray.add(Step(
            title: (steps[step].title != null)
                ? steps[step].title
                : Text(cons.sampleText),
            subtitle: (steps[step].subtitle != null)
                ? steps[step].subtitle
                : Text(cons.sampleText),
            content: (steps[step].content != null)
                ? steps[step].content
                : IconButton(icon: Icon(cons.icon1)),
            state: (steps[step].state != null)
                ? steps[step].state
                : currentStep == step
                    ? listState[1]
                    : currentStep > step ? listState[2] : listState[0],
            isActive: (steps[step].isActive != null)
                ? steps[step].isActive
                : currentStep == step ? true : false));
      }
    } else {
      Step step1 = new Step(
          title: Text(cons.listTitle),
          subtitle: Text(cons.listSubtitle),
          content: IconButton(
            icon: Icon(Icons.add_alarm),
            onPressed: () {},
          ),
          state: currentStep == 0
              ? listState[1]
              : currentStep > 0 ? listState[2] : listState[0],
          isActive: currentStep == 0 ? true : false);

      Step step2 = new Step(
          title: Text(cons.listTitle),
          subtitle: Text(cons.listSubtitle),
          content: IconButton(
            icon: Icon(Icons.add_alarm),
            onPressed: () {},
          ),
          state: currentStep == 1
              ? listState[1]
              : currentStep > 0 ? listState[2] : listState[0],
          isActive: currentStep == 1 ? true : false);
      stepArray.add(step1);
      stepArray.add(step2);
    }
    return stepArray;
  }

  @override
  Widget build(BuildContext context) {
    List<Step> stepArray = _createSteps(context);

    goTo(int step) {
      setState(() => currentStep = step);
    }

    defaultNext() {
      setState(() {
        if (currentStep < stepArray.length - 1) {
          currentStep = currentStep + 1;
        } else {
          currentStep = stepArray.length - 1;
          complete = true;
        }
      });
    }

    defaultCancel() {
      setState(() {
        if (currentStep > 0) {
          currentStep--;
        } else {
          currentStep = 0;
        }
        //_setStep(context);
      });
    }

    if (stepperParams != null) {
      return Scaffold(
        backgroundColor: Colors.black,
        body:Column(
              children: <Widget>[
                Expanded(
                  child: Stepper(
                    steps: stepArray,
                    currentStep:
                        currentStep < stepArray.length ? currentStep : 0,
                    type: (stepperParams.type != null)
                        ? stepperParams.type
                        : StepperType.vertical,
                    onStepContinue: (onContinue != null)
                        ? onContinue
                        : defaultNext,
                    onStepTapped: (onTapped != null)
                        ? onTapped
                        : (step) => goTo(step),
                    onStepCancel: (onCancel != null)
                        ? onCancel
                        : defaultCancel,
                  ),
                )
              ],
            ),
      );
    }
    else{
      return Scaffold(
        body: Theme(
            data: MediumGreyThemeData(),
            child: Column(
              children: <Widget>[
                Expanded(
                  child: Stepper(
                    steps: stepArray,
                    currentStep: 0,
                    type: StepperType.vertical,
                    onStepContinue: defaultNext,
                    onStepTapped: (step) => goTo(step),
                    onStepCancel: defaultCancel,
                  ),
                )
              ],
            )),
      );
    }
  }
}
