/*
Description:
A widget that dynamically creates a tooltip functionality around a widget (Usually a Button).
On long pressing the button, we get some information around its usage as a hovering text.

Usage:
The user can pass in a widget and the text that is supposed to be displayed.
The user can also pass on parameters like height, padding, margin etc.
See CustomToolTipData and CustomToolTipParameters class definitons for more information.
The user also passes a callback function which is invoked when the ToolTip is used. 
- The widget returns a boolean value to showcase if the tooltip was used or not.
    
    CustomToolTipData tooltipElement = new CustomToolTipData(child: RaisedButton(...), messsage: "This is a ToolTip");
    CustomToolTipParameters tooltipParameters = new CustomToolTipParameters(height: 10, padding: 5);
    CustomToolTip(tooltipElement, tooltipParameters, callback);

Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'package:flutter_widgets_library/theme/theme.dart';
import 'package:flutter_widgets_library/utils/consts.dart' as cons;
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';

Widget CustomToolTip(CustomToolTipData tooltipData, CustomToolTipParameters tooltipParameters,
    Function(bool) callback) {
  // If no parameters are passed to the Widget
  if (tooltipParameters == null || tooltipData == null) {
    return Tooltip(
      message: cons.sampleText,
      child: RaisedButton(
        child: Icon(cons.icon1, color: MediumGreyThemeData().iconTheme.color),
        onPressed: () {
          return callback(true);
        },
        color: MediumGreyThemeData().floatingActionButtonTheme.backgroundColor,
      ),
      height: cons.heightTwentyPixel,
      decoration: BoxDecoration(color: MediumGreyThemeData().primaryColorDark),
    );
  } else {
    // If all or limited parameters are passed to the Widget
    return Tooltip(
      message: (tooltipData.message == null || tooltipData.message == "")
          ? cons.sampleText
          : tooltipData.message,
      child: (tooltipData.child != null)
          ? tooltipData.child
          : RaisedButton(
              child: Icon(cons.icon2,
                  color: MediumGreyThemeData().iconTheme.color),
              onPressed: () {
                return callback(true);
              },
              color: MediumGreyThemeData()
                  .floatingActionButtonTheme
                  .backgroundColor,
            ),
      height: (tooltipParameters.height != null) ? tooltipParameters.height : cons.heightTwentyPixel,
      decoration: (tooltipParameters.decoration != null)
          ? tooltipParameters.decoration
          : BoxDecoration(color: MediumGreyThemeData().primaryColorDark),
    );
  }
}
